#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2016-04-08
#
#
# 2023-06-14: moved wato file to check_parameters sub directory

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    HostRulespec,
    rulespec_registry,
)
from cmk.gui.valuespec import (
    Dictionary,
    FixedValue,
    TextAscii,
    ListChoice,
)

from cmk.gui.plugins.wato.inventory import (
    RulespecGroupInventory,
)

_removecolumns_cisco_wlc_ap_cdp_cache = [
    ('duplex', 'Duplex'),
    ('speed', 'Speed'),
]


def _valuespec_inv_cisco_wlc_ap_cdp_cache():
    return Dictionary(
        title=_('Cisco WLC AP CDP cache'),
        elements=[
            ('remove_domain',
             FixedValue(
                 True,
                 title=_('Remove domain name from neighbour device name'),
                 totext=_('Remove the domain name enabled'),
                 default_value=False,
             )),
            ('domain_name',
             TextAscii(
                 title=_('Specific domain name to remove from neighbour device name'),
                 allow_empty=False,
                 default_value='',
             )),
            ('removecolumns',
             ListChoice(
                 title=_('List of columns to remove'),
                 help=_('information to remove from inventory'),
                 choices=_removecolumns_cisco_wlc_ap_cdp_cache,
                 default_value=[],
             )),
            ('use_short_if_name',
             FixedValue(
                 True,
                 title=_('use short interface names (i.e. Gi0/0 for GigabitEthernet0/0)'),
                 totext=_('use short interface names enabled'),
                 default_value=False,
             )),
        ],
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupInventory,
        match_type='dict',
        name='inv_parameters:inv_cisco_wlc_ap_cdp_cache',
        valuespec=_valuespec_inv_cisco_wlc_ap_cdp_cache,
    ))
